@@ -4,7 +4,7 @@ use 5.010;
 use Data::Printer;
 use feature qw(say);
 # Since 2.99 it got a is_core() method :)
-use Module::CoreList;
+use Module::CoreList 2.99;
 use Module::Version 'get_version';
 use autodie;
 use Moose;
@@ -14,11 +14,12 @@ use Cwd;
 use Log::Minimal env_debug => 'LM_DEBUG';
 use File::Stamped;
 use IO::File;
+use File::Temp;
 
 # This module will be used throught a system call
 # App::Ack;
 
-our $VERSION = '0.05_04';
+our $VERSION = '0.05_05';
 
 =head1 NAME
 
@@ -105,9 +106,10 @@ has 'core_modules' => (
 #  * * * * * * * * * * * * * * *
 
 $ENV{LM_DEBUG} = 1;
-my $current_dir = getcwd();
+my $tmp = '/tmp';
+
 my $log_fh = File::Stamped->new(
-    pattern => "$current_dir/t/dependencies-searcher.%Y-%m-%d.out",
+    pattern => $tmp . "/dependencies-searcher.%Y-%m-%d.out",
 );
 
 # Overrides Log::Minimal PRINT
@@ -117,6 +119,7 @@ $Log::Minimal::PRINT = sub {
 };
 
 debugf("Dependencies::Searcher 0.05_03 debugger init.");
+debugf("Log file available in /tmp");
 
 #  * * * * * * * * * * * * * * *
 
@@ -248,6 +251,10 @@ sub clean_everything {
 	# Remove some warning sugar
 	$module =~ s/([a-z]+)\sFATAL\s=>\s'all'/$1/i;
 
+	# Remove version numbers
+	# http://stackoverflow.com/questions/82064/a-regex-for-version-number-parsing
+	$module =~ s/\s(\*|\d+(\.\d+){0,2}(\.\*)?)$//;
+
 	push @clean_modules, $module;
     }
     return @clean_modules;
@@ -266,6 +273,11 @@ sub uniq {
 }
 
 
+#
+# BUG !!! https://github.com/smonff/dependencies-searcher/issues/25
+#
+# Recent versions of corelist modules are not in corelist but this code portion acts just like it would
+#
 sub dissociate {
     my ($self, @common_modules) = @_;
 
@@ -274,6 +286,8 @@ sub dissociate {
 	# my $core_list_answer = `corelist $nc_module`;
 	my $core_list_answer = Module::CoreList::is_core($nc_module);
 
+	# debugf("$nc_module version : " .  $Module::CoreList::version{ $] }{"$nc_module"});
+
 	# print "Found " . $nc_module;
 	if (
 	    (exists $Module::CoreList::version{ $] }{"$nc_module"})
@@ -308,9 +322,6 @@ sub generate_report {
 
     foreach my $module_name ( @{$self->non_core_modules} ) {
 
-	# From Module::Version command line utility
-	# BUG : should use IPC::Cmd instead of backquotes
-	# or even better use the module's perl API but not the command line :(
 	my $version = get_version($module_name);
 	debugf($module_name);
 	debugf $version;
@@ -411,6 +422,12 @@ Generate the cpanfile for Carton, with optionnal version number
 
 =cut
 
+=head2 Log::Minimal::PRINT override
+
+Just override the way Log::Minimal is used. We create a .out file in ./t directory. To see log, use tail -v /path/to/the/module/t/dependencies-searcher.[y-M-d].out
+
+=cut
+
 =head1 AUTHOR
 
 smonff, C<< <smonff at gmail.com> >>
